Learn R Programming

gplots (version 3.0.0)

gplots-defunct: Defunct functions

Description

These functions are defunct and have been removed from the gplots package.

Usage

boxplot.n(..., top=FALSE, shrink=1, textcolor=NULL)
   plot.lm2(
            x,
            which = 1:5,
            caption = c("Residuals vs Fitted", "Normal Q-Q plot",
              "Scale-Location plot", "Cook's distance plot"),
            panel = panel.smooth,
            sub.caption = deparse(x$call),
            main = "",
            ask,
            ...,
            id.n = 3,
            labels.id = names(residuals(x)),
            cex.id = 0.75,
            band=TRUE,
            rug=TRUE,
            width=1/10,
            max.n=5000
            )
  smartlegend(x = c("left", "center", "right"),
             y = c("top", "center", "bottom"),
             ...,
             inset = 0.05)

Arguments

ask, band, caption, cex.id, id.n, inset, labels.id, main, max.n, panel, rug, shrink, sub.caption, textcolor, top, which, width,
see man page for the corresponding replacement function

Details

These functions are no longer available. Please refer to the manual page for the replacement function:
  • boxplot.nhas been replaced byboxplot2
  • plot.lm2has been replaced bylmplot2
  • smartlegendis no longer needed because relative positioning has been implemented inlegend.

See Also

boxplot2, lmplot2, legend, Defunct