Learn R Programming

gplots (version 2.17.0)

gplots-defunct: Defunct functions

Description

These funcntion are defunct and have been removed from the gplots package.

Usage

boxplot.n(..., top=FALSE, shrink=1, textcolor=NULL)
   plot.lm2(
            x,
            which = 1:5,
            caption = c("Residuals vs Fitted", "Normal Q-Q plot",
              "Scale-Location plot", "Cook's distance plot"),
            panel = panel.smooth,
            sub.caption = deparse(x$call),
            main = "",
            ask,
            ...,
            id.n = 3,
            labels.id = names(residuals(x)),
            cex.id = 0.75,
            band=TRUE,
            rug=TRUE,
            width=1/10,
            max.n=5000
            )

Arguments

...
see man page for the corresponding replacement function
top, shrink, textcolor
See man page for boxplot2.
x, which, caption, panel, sub.caption, main, ask, id.n, labels.id, cex.id, band, rug, width, max.n
See man page for lmplot2.

Details

These functions are no longer available. Please refer to the manual page for the replacement function:

See Also

boxplot2, lmplot2, Defunct