Learn R Programming

gplots (version 2.17.0)

gplots-deprecated: Deprecated functions

Description

These funcntion have been deprecated and will be removed in future releases of gplots.

Usage

smartlegend(x = c("left", "center", "right"),
            y = c("top", "center", "bottom"),
            ...,
            inset = 0.05)

Arguments

x, y, inset, ...
see man page for the corresponding replacement function

Details

These functions have been deprecated. Please refer to the manual page for the replacement function:
  • smartlegendis no longer needed because relative positioning has been implemented in graphics::legend().

See Also

legend, Deprecated